@@ -151,9 +151,9 @@ wordfish_rank_plot <- function(
     data2 <- reshape2::melt(data2)
     data4 <- reshape2::melt(data4)
 
-    # data1$labels <- factor(data1$labels, levels = rev(data1$labels))
-    # data2$labels <- factor(data2$labels, levels = rev(data2$labels))
-    # data4$labels <- factor(data4$labels, levels = rev(data4$labels))
+    # we need to do this manual reordering of the labels so that we can show
+    # things in order from most to least similar to the a-priori ordering.
+    data4$labels <- factor(data4$labels, levels = rev(data$labels))
 
     #make the plot
     UMASS_BLUE <- rgb(51,51,153,255,maxColorValue = 255)
